@@ -9,7 +9,6 @@ import os
 import subprocess
 import sys
 import time
-from datetime import UTC, datetime, timedelta
 
 import git
 import typer
@@ -75,12 +74,17 @@ def clone(
     no_dvc_pull: Annotated[
         bool, typer.Option("--no-dvc-pull", help="Do not pull DVC objects.")
     ] = False,
+    recursive: Annotated[
+        bool, typer.Option("--recursive", help="Recursively clone submodules.")
+    ] = False,
 ):
     """Clone a Git repo and by default configure and pull from the DVC
     remote.
     """
     # Git clone
     cmd = ["git", "clone", url]
+    if recursive:
+        cmd.append("--recursive")
     if location is not None:
         cmd.append(location)
     try:
@@ -404,7 +408,12 @@ def run_dvc_repro(
                         f"Stage {stage_name} does not have exactly one output"
                     )
                 cktype = ckmeta.get("type")
-                if cktype not in ["figure", "dataset", "publication"]:
+                if cktype not in [
+                    "figure",
+                    "dataset",
+                    "publication",
+                    "notebook",
+                ]:
                     raise_error(f"Invalid Calkit output type '{cktype}'")
                 objects.append(
                     dict(path=outs[0]) | ckmeta | dict(stage=stage_name)
@@ -601,6 +610,9 @@ def build_docker(
     fpath: Annotated[
         str, typer.Option("-i", "--input", help="Path to input Dockerfile.")
     ] = "Dockerfile",
+    platform: Annotated[
+        str, typer.Option("--platform", help="Which platform(s) to build for.")
+    ] = None,
 ):
     def get_docker_inspect():
         out = json.loads(
@@ -640,7 +652,11 @@ def build_docker(
             "Layers"
         ] or dockerfile_md5 != lock[0].get("DockerfileMD5")
     if rebuild:
-        subprocess.check_call(["docker", "build", "-t", tag, "-f", fpath, "."])
+        cmd = ["docker", "build", "-t", tag, "-f", fpath]
+        if platform is not None:
+            cmd += ["--platform", platform]
+        cmd.append(".")
+        subprocess.check_call(cmd)
     # Write the lock file
     inspect = get_docker_inspect()
     inspect[0]["DockerfileMD5"] = dockerfile_md5
@@ -806,7 +822,7 @@ def check_conda_env(
             "-o",
             help=(
                 "Path to which existing environment should be exported. "
-                "If not specified, will have the same filename with '-loc' "
+                "If not specified, will have the same filename with '-lock' "
                 "appended to it, keeping the same extension."
             ),
         ),
